@@ -3,15 +3,18 @@ command."""
 
 try:
     from wheel.wheelfile import WheelFile
+
     _USE_WHEELFILE = True
 except ImportError:
     from wheel import archive as _wheel_archive  # Not available with wheel >= 0.32.0
+
     _USE_WHEELFILE = False
 
 from wheel.bdist_wheel import bdist_wheel as _bdist_wheel
 
-from . import set_build_base_mixin
+from .. import __version__ as skbuild_version
 from ..utils import distribution_hide_listing, new_style
+from . import set_build_base_mixin
 
 
 class bdist_wheel(set_build_base_mixin, new_style(_bdist_wheel)):
@@ -27,8 +30,7 @@ class bdist_wheel(set_build_base_mixin, new_style(_bdist_wheel)):
                 with distribution_hide_listing(self.distribution) as hide_listing:
                     if hide_listing:
                         zip_filename = wheelfile_self.filename
-                        print("creating '%s' and adding '%s' to it"
-                              % (zip_filename, base_dir))
+                        print("creating '{}' and adding '{}' to it".format(zip_filename, base_dir))
                     old_write_files(wheelfile_self, base_dir)
 
             WheelFile.distribution = self.distribution
@@ -42,12 +44,11 @@ class bdist_wheel(set_build_base_mixin, new_style(_bdist_wheel)):
         else:
             old_make_wheelfile_inner = _wheel_archive.make_wheelfile_inner
 
-            def _make_wheelfile_inner(base_name, base_dir='.'):
+            def _make_wheelfile_inner(base_name, base_dir="."):
                 with distribution_hide_listing(self.distribution) as hide_listing:
                     if hide_listing:
                         zip_filename = base_name + ".whl"
-                        print("creating '%s' and adding '%s' to it"
-                              % (zip_filename, base_dir))
+                        print("creating '{}' and adding '{}' to it".format(zip_filename, base_dir))
                     old_make_wheelfile_inner(base_name, base_dir)
 
             _wheel_archive.make_wheelfile_inner = _make_wheelfile_inner
@@ -61,6 +62,5 @@ class bdist_wheel(set_build_base_mixin, new_style(_bdist_wheel)):
         """Write ``skbuild <version>`` as a wheel generator.
         See `PEP-0427 <https://www.python.org/dev/peps/pep-0427/#file-contents>`_ for more details.
         """
-        from .. import __version__ as skbuild_version
         generator = "skbuild %s" % skbuild_version
         super(bdist_wheel, self).write_wheelfile(wheelfile_base, generator)
