@@ -2,9 +2,8 @@
 
 import os
 
-from .abstract import CMakeGenerator
-
 from . import abstract
+from .abstract import CMakeGenerator
 
 
 # pylint:disable=abstract-method
@@ -14,13 +13,11 @@ class UnixPlatform(abstract.CMakePlatform):
     def __init__(self):
         super(UnixPlatform, self).__init__()
         try:
-            import ninja
+            import ninja  # pylint: disable=import-outside-toplevel
+
             ninja_executable_path = os.path.join(ninja.BIN_DIR, "ninja")
-            ninja_args = ['-DCMAKE_MAKE_PROGRAM:FILEPATH=' + ninja_executable_path]
+            ninja_args = ["-DCMAKE_MAKE_PROGRAM:FILEPATH=" + ninja_executable_path]
         except ImportError:
             ninja_args = []
 
-        self.default_generators = [
-            CMakeGenerator("Ninja", args=ninja_args),
-            CMakeGenerator("Unix Makefiles")
-        ]
+        self.default_generators = [CMakeGenerator("Ninja", args=ninja_args), CMakeGenerator("Unix Makefiles")]
