@@ -8,102 +8,10 @@ import re
 import subprocess
 import sys
 import textwrap
-
 from itertools import count
 
-from .abstract import CMakeGenerator
-
 from . import abstract
-
-
-class WindowsPlatform(abstract.CMakePlatform):
-    """Windows implementation of :class:`.abstract.CMakePlatform`."""
-
-    def __init__(self):
-        super(WindowsPlatform, self).__init__()
-        version = sys.version_info
-        self._vs_help = ""
-        vs_help_template = textwrap.dedent(
-            """
-            Building windows wheels for Python {pyver} requires Microsoft Visual Studio %s.
-            Get it with "%s":
-
-              %s
-            """  # noqa: E501
-        ).strip().format(pyver="%s.%s" % sys.version_info[:2])
-
-        # For Python 2.7 to Python 3.2: VS2008
-        if (
-            (version.major == 2 and version.minor >= 7) or
-            (version.major == 3 and version.minor <= 2)
-        ):
-            supported_vs_years = [("2008", None)]
-            self._vs_help = vs_help_template % (
-                supported_vs_years[0][0],
-                "Microsoft Visual C++ Compiler for Python 2.7",
-                "http://aka.ms/vcpython27"
-            )
-
-        # For Python 3.3 to Python 3.4: VS2010
-        elif (
-            version.major == 3 and (
-                version.minor >= 3 and
-                version.minor <= 4
-            )
-        ):
-            supported_vs_years = [("2010", None)]
-            self._vs_help = vs_help_template % (
-                supported_vs_years[0][0],
-                "Windows SDK for Windows 7 and .NET 4.0",
-                "https://www.microsoft.com/download/details.aspx?id=8279"
-            )
-
-        # For Python 3.5: VS2019, VS2017, VS2015
-        elif version.major == 3 and version.minor == 5:
-            supported_vs_years = [("2019", "v142"), ("2017", "v140"), ("2015", None)]
-            self._vs_help = vs_help_template % (
-                supported_vs_years[0][0],
-                "Visual Studio 2015",
-                "https://visualstudio.microsoft.com/vs/older-downloads/"
-            )
-            self._vs_help += "\n\n" + textwrap.dedent(
-                """
-                Or with "Visual Studio 2017" or "Visual Studio 2019":
-
-                  https://visualstudio.microsoft.com/vs/
-                """
-            ).strip()
-
-        # For Python 3.6 and above: VS2019, VS2017
-        elif version.major == 3 and version.minor >= 6:
-            supported_vs_years = [("2019", "v142"), ("2017", "v141")]
-            self._vs_help = vs_help_template % (
-                supported_vs_years[0][0],
-                "Visual Studio 2017",
-                "https://visualstudio.microsoft.com/vs/"
-            )
-            self._vs_help += "\n\n" + textwrap.dedent(
-                """
-                Or with "Visual Studio 2019":
-
-                  https://visualstudio.microsoft.com/vs/
-                """
-            ).strip()
-        else:
-            raise RuntimeError("Only Python >= 2.7 is supported on Windows.")
-
-        for vs_year, vs_toolset in supported_vs_years:
-            self.default_generators.extend([
-                CMakeVisualStudioCommandLineGenerator("Ninja", vs_year, vs_toolset),
-                CMakeVisualStudioIDEGenerator(vs_year, vs_toolset),
-                CMakeVisualStudioCommandLineGenerator("NMake Makefiles", vs_year, vs_toolset),
-            ])
-
-    @property
-    def generator_installation_help(self):
-        """Return message guiding the user for installing a valid toolchain."""
-        return self._vs_help
-
+from .abstract import CMakeGenerator
 
 VS_YEAR_TO_VERSION = {
     "2008": 9,
@@ -113,6 +21,7 @@ VS_YEAR_TO_VERSION = {
     "2015": 14,
     "2017": 15,
     "2019": 16,
+    "2022": 17,
 }
 """Describes the version of `Visual Studio` supported by
 :class:`CMakeVisualStudioIDEGenerator` and
@@ -121,6 +30,125 @@ VS_YEAR_TO_VERSION = {
 The different version are identified by their year.
 """
 
+VS_YEAR_TO_MSC_VER = {
+    "2008": "1500",  # VS 2008
+    "2010": "1600",  # VS 2010
+    "2012": "1700",  # VS 2012
+    "2013": "1800",  # VS 2012
+    "2015": "1900",  # VS 2015
+    "2017": "1910",  # VS 2017 - can be +9
+    "2019": "1920",  # VS 2019 - can be +9
+    "2022": "1930",  # VS 2022 - can be +9
+}
+
+
+class WindowsPlatform(abstract.CMakePlatform):
+    """Windows implementation of :class:`.abstract.CMakePlatform`."""
+
+    def __init__(self):
+        super(WindowsPlatform, self).__init__()
+        self._vs_help = ""
+        vs_help_template = (
+            textwrap.dedent(
+                """
+            Building windows wheels for Python {pyver} requires Microsoft Visual Studio %s.
+            Get it with "%s":
+
+              %s
+            """  # noqa: E501
+            )
+            .strip()
+            .format(pyver="%s.%s" % sys.version_info[:2])
+        )
+
+        # For Python 2.7 to Python 3.2: VS2008
+        if (2, 7) <= sys.version_info < (3, 3):
+            supported_vs_years = [("2008", None)]
+            self._vs_help = vs_help_template % (
+                supported_vs_years[0][0],
+                "Microsoft Visual C++ Compiler for Python 2.7",
+                "http://aka.ms/vcpython27",
+            )
+
+        # For Python 3.3 to Python 3.4: VS2010
+        elif (3, 3) <= sys.version_info < (3, 5):
+            supported_vs_years = [("2010", None)]
+            self._vs_help = vs_help_template % (
+                supported_vs_years[0][0],
+                "Windows SDK for Windows 7 and .NET 4.0",
+                "https://www.microsoft.com/download/details.aspx?id=8279",
+            )
+
+        # For Python 3.5: VS2019, VS2017, VS2015
+        elif (3, 5) <= sys.version_info < (3, 6):
+            supported_vs_years = [("2019", "v142"), ("2017", "v140"), ("2015", None)]
+            self._vs_help = vs_help_template % (
+                supported_vs_years[0][0],
+                "Visual Studio 2015",
+                "https://visualstudio.microsoft.com/vs/older-downloads/",
+            )
+            self._vs_help += (
+                "\n\n"
+                + textwrap.dedent(
+                    """
+                Or with "Visual Studio 2017" or "Visual Studio 2019":
+
+                  https://visualstudio.microsoft.com/vs/
+                """
+                ).strip()
+            )
+
+        # For Python 3.6 and above: VS2022, VS2019, VS2017
+        elif (3, 6) <= sys.version_info:
+            supported_vs_years = [("2022", "v143"), ("2019", "v142"), ("2017", "v141")]
+            self._vs_help = vs_help_template % (
+                supported_vs_years[0][0],
+                "Visual Studio 2017",
+                "https://visualstudio.microsoft.com/vs/",
+            )
+            self._vs_help += (
+                "\n\n"
+                + textwrap.dedent(
+                    """
+                Or with "Visual Studio 2019":
+
+                  https://visualstudio.microsoft.com/vs/
+
+                Or with "Visual Studio 2022":
+
+                  https://visualstudio.microsoft.com/vs/
+                """
+                ).strip()
+            )
+        else:
+            raise RuntimeError("Only Python >= 2.7 is supported on Windows.")
+
+        try:
+            import ninja  # pylint: disable=import-outside-toplevel
+
+            ninja_executable_path = os.path.join(ninja.BIN_DIR, "ninja")
+            ninja_args = ["-DCMAKE_MAKE_PROGRAM:FILEPATH=" + ninja_executable_path]
+        except ImportError:
+            ninja_args = []
+
+        extra = []
+        for vs_year, vs_toolset in supported_vs_years:
+            vs_version = VS_YEAR_TO_MSC_VER[vs_year]
+            args = ["-D_SKBUILD_FORCE_MSVC={}".format(vs_version)]
+            self.default_generators.extend(
+                [
+                    CMakeVisualStudioCommandLineGenerator("Ninja", vs_year, vs_toolset, args=ninja_args + args),
+                    CMakeVisualStudioIDEGenerator(vs_year, vs_toolset),
+                ]
+            )
+            extra.append(CMakeVisualStudioCommandLineGenerator("NMake Makefiles", vs_year, vs_toolset, args=args))
+        self.default_generators.extend(extra)
+
+    @property
+    def generator_installation_help(self):
+        """Return message guiding the user for installing a valid toolchain."""
+        return self._vs_help
+
 
 class CMakeVisualStudioIDEGenerator(CMakeGenerator):
     """
@@ -128,6 +156,7 @@ class CMakeVisualStudioIDEGenerator(CMakeGenerator):
 
     .. automethod:: __init__
     """
+
     def __init__(self, year, toolset=None):
         """Instantiate a generator object with its name set to the `Visual
         Studio` generator associated with the given ``year``
@@ -135,8 +164,10 @@ class CMakeVisualStudioIDEGenerator(CMakeGenerator):
         or 64-bit) and the selected ``toolset`` (if applicable).
         """
         vs_version = VS_YEAR_TO_VERSION[year]
-        vs_base = "Visual Studio %s %s" % (vs_version, year)
-        if platform.architecture()[0] == "64bit":
+        vs_base = "Visual Studio {} {}".format(vs_version, year)
+        if platform.machine() == "ARM64":
+            vs_arch = "ARM64"
+        elif platform.architecture()[0] == "64bit":
             vs_arch = "x64"
         else:
             vs_arch = "Win32"
@@ -158,11 +189,11 @@ def _find_visual_studio_2010_to_2015(vs_version):
     """
     # winreg module
     try:
-        import winreg
+        import winreg  # pylint: disable=import-outside-toplevel
     except ImportError:
         # Support Python 2.7
         try:
-            import _winreg as winreg
+            import _winreg as winreg  # pylint: disable=import-outside-toplevel
         except ImportError:
             return ""
 
@@ -172,7 +203,7 @@ def _find_visual_studio_2010_to_2015(vs_version):
             winreg.HKEY_LOCAL_MACHINE,
             r"Software\Microsoft\VisualStudio\SxS\VC7",
             0,
-            winreg.KEY_READ | winreg.KEY_WOW64_32KEY
+            winreg.KEY_READ | winreg.KEY_WOW64_32KEY,
         )
     except OSError:
         return ""
@@ -213,16 +244,24 @@ def _find_visual_studio_2017_or_newer(vs_version):
 
     try:
         extra_args = {}
-        if sys.version_info[:3] >= (3, 6, 0):
-            extra_args = {'encoding': 'mbcs', 'errors': 'strict'}
-        path = subprocess.check_output([
-            os.path.join(root, "Microsoft Visual Studio", "Installer", "vswhere.exe"),
-            "-version", "[%.1f, %.1f)" % (vs_version, vs_version + 1),
-            "-prerelease",
-            "-requires", "Microsoft.VisualStudio.Component.VC.Tools.x86.x64",
-            "-property", "installationPath",
-            "-products", "*",
-        ], **extra_args).strip()
+        if sys.version_info >= (3, 6):
+            extra_args["encoding"] = "utf-8" if sys.platform.startswith("cygwin") else "mbcs"
+            extra_args["errors"] = "strict"
+        path = subprocess.check_output(
+            [
+                os.path.join(root, "Microsoft Visual Studio", "Installer", "vswhere.exe"),
+                "-version",
+                "[{:.1f}, {:.1f})".format(vs_version, vs_version + 1),
+                "-prerelease",
+                "-requires",
+                "Microsoft.VisualStudio.Component.VC.Tools.x86.x64",
+                "-property",
+                "installationPath",
+                "-products",
+                "*",
+            ],
+            **extra_args
+        ).strip()
         if (3, 0) <= sys.version_info[:2] <= (3, 5):
             path = path.decode()
     except (subprocess.CalledProcessError, OSError, UnicodeDecodeError):
@@ -253,15 +292,16 @@ def find_visual_studio(vs_version):
     """
     if 15 <= vs_version:
         return _find_visual_studio_2017_or_newer(vs_version)
-    elif 10 <= vs_version <= 14:
+
+    if 10 <= vs_version <= 14:
         return _find_visual_studio_2010_to_2015(vs_version)
-    else:
-        return ""
+
+    return ""
 
 
 # To avoid multiple slow calls to ``subprocess.check_output()`` (either directly or
 # indirectly through ``query_vcvarsall``), results of previous calls are cached.
-__get_msvc_compiler_env_cache = dict()
+__get_msvc_compiler_env_cache = {}
 
 
 def _get_msvc_compiler_env(vs_version, vs_toolset=None):
@@ -274,12 +314,12 @@ def _get_msvc_compiler_env(vs_version, vs_toolset=None):
     If specified, ``vs_toolset`` is used to set the `-vcvars_ver=XX.Y` argument passed to
     ``vcvarsall.bat`` script.
     """
-    # pylint:disable=global-statement
-    global __get_msvc_compiler_env_cache
 
     # Set architecture
     arch = "x86"
-    if platform.architecture()[0] == "64bit":
+    if platform.machine() == "ARM64":
+        arch = "x86_arm64"
+    elif platform.architecture()[0] == "64bit":
         if vs_version < 14:
             arch = "amd64"
         else:
@@ -290,12 +330,14 @@ def _get_msvc_compiler_env(vs_version, vs_toolset=None):
     if cache_key in __get_msvc_compiler_env_cache:
         return __get_msvc_compiler_env_cache[cache_key]
 
-    from setuptools import monkey
+    from setuptools import monkey  # pylint: disable=import-outside-toplevel
+
     monkey.patch_for_msvc_specialized_compiler()
 
     if vs_version < 14:
         try:
-            import distutils.msvc9compiler
+            import distutils.msvc9compiler  # pylint: disable=import-outside-toplevel
+
             cached_env = distutils.msvc9compiler.query_vcvarsall(vs_version, arch)
             __get_msvc_compiler_env_cache[cache_key] = cached_env
             return cached_env
@@ -315,25 +357,26 @@ def _get_msvc_compiler_env(vs_version, vs_toolset=None):
                 vcvars_ver = "-vcvars_ver=%s.%s" % match
 
         try:
+            # TODO: should always be shell=True, but currently requires this
             out = subprocess.check_output(
                 'cmd /u /c "{}" {} {} && set'.format(vcvarsall, arch, vcvars_ver),
                 stderr=subprocess.STDOUT,
+                shell=sys.platform.startswith("cygwin"),
             )
-            out = out.decode('utf-16le', errors='replace')
+            out = out.decode("utf-16le", errors="replace")
             if sys.version_info[0] < 3:
-                out = out.encode('utf-8')
+                out = out.encode("utf-8")
 
             vc_env = {
                 key.lower(): value
-                for key, _, value in
-                (line.partition('=') for line in out.splitlines())
+                for key, _, value in (line.partition("=") for line in out.splitlines())
                 if key and value
             }
 
             cached_env = {
-                'PATH': vc_env.get('path', ''),
-                'INCLUDE': vc_env.get('include', ''),
-                'LIB': vc_env.get('lib', '')
+                "PATH": vc_env.get("path", ""),
+                "INCLUDE": vc_env.get("include", ""),
+                "LIB": vc_env.get("lib", ""),
             }
             __get_msvc_compiler_env_cache[cache_key] = cached_env
             return cached_env
@@ -350,7 +393,8 @@ class CMakeVisualStudioCommandLineGenerator(CMakeGenerator):
 
     .. automethod:: __init__
     """
-    def __init__(self, name, year, toolset=None):
+
+    def __init__(self, name, year, toolset=None, args=None):
         """Instantiate CMake command-line generator.
 
         The generator ``name`` can be values like `Ninja`, `NMake Makefiles`
@@ -366,5 +410,5 @@ class CMakeVisualStudioCommandLineGenerator(CMakeGenerator):
         """
         vc_env = _get_msvc_compiler_env(VS_YEAR_TO_VERSION[year], toolset)
         env = {str(key.upper()): str(value) for key, value in vc_env.items()}
-        super(CMakeVisualStudioCommandLineGenerator, self).__init__(name, env)
-        self._description = "%s (%s)" % (self.name, CMakeVisualStudioIDEGenerator(year, toolset).description)
+        super(CMakeVisualStudioCommandLineGenerator, self).__init__(name, env, args=args)
+        self._description = "{} ({})".format(self.name, CMakeVisualStudioIDEGenerator(year, toolset).description)
